@@ -1,19 +1,21 @@
 package Business::ID::NKK;
 
-our $DATE = '2018-04-08'; # DATE
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use warnings;
 use strict;
 
 use DateTime;
-use Locale::ID::Locality qw(list_id_localities);
-use Locale::ID::Province qw(list_id_provinces);
-
 use Exporter qw(import);
+use Locale::ID::Locality qw(list_idn_localities);
+use Locale::ID::Province qw(list_idn_provinces);
+
 our @EXPORT_OK = qw(parse_nkk);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-10-04'; # DATE
+our $DIST = 'Business-ID-NKK'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 our %SPEC;
 
 $SPEC{parse_nkk} = {
@@ -41,7 +43,7 @@ sub parse_nkk {
 
     state $provinces;
     if (!$provinces) {
-        my $res = list_id_provinces(detail => 1);
+        my $res = list_idn_provinces(detail => 1);
         return [500, "Can't get list of provinces: $res->[0] - $res->[1]"]
             if $res->[0] != 200;
         $provinces = { map {$_->{bps_code} => $_} @{$res->[2]} };
@@ -63,7 +65,7 @@ sub parse_nkk {
 
     $res->{loc_code}  = substr($nkk, 0, 4);
     if ($args{check_locality} // 1) {
-        my $lres = list_id_localities(
+        my $lres = list_idn_localities(
             detail => 1, bps_code => $res->{loc_code});
         return [500, "Can't check locality: $lres->[0] - $lres->[1]"]
             unless $lres->[0] == 200;
@@ -101,7 +103,7 @@ Business::ID::NKK - Parse Indonesian family card number (nomor kartu keluarga, N
 
 =head1 VERSION
 
-This document describes version 0.002 of Business::ID::NKK (from Perl distribution Business-ID-NKK), released on 2018-04-08.
+This document describes version 0.003 of Business::ID::NKK (from Perl distribution Business-ID-NKK), released on 2023-10-04.
 
 =head1 SYNOPSIS
 
@@ -132,7 +134,7 @@ Keywords: nomor KK, family registration number
 
 Usage:
 
- parse_nkk(%args) -> [status, msg, result, meta]
+ parse_nkk(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Parse Indonesian family card number (nomor kartu keluarga, NKK).
 
@@ -154,16 +156,17 @@ Whether to check for known province codes.
 
 Input NKK to be validated.
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -175,14 +178,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 Source repository is at L<https://github.com/perlancar/perl-Business-ID-NKK>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-NKK>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Business::ID::NIK> to parse NIK (nomor induk kependudukan, nomor KTP)
@@ -191,11 +186,37 @@ L<Business::ID::NIK> to parse NIK (nomor induk kependudukan, nomor KTP)
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-NKK>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
